100k bytes

Bug: skia:
Change-Id: Iebbd9293878ceff952546a8f7e0b979bd92eba22
Reviewed-on: https://skia-review.googlesource.com/c/178866
Reviewed-by: Joe Gregorio <jcgregorio@google.com>
Reviewed-by: Kevin Lubick <kjlubick@google.com>
Commit-Queue: Kevin Lubick <kjlubick@google.com>
diff --git a/jsfiddle/go/jsfiddle/main.go b/jsfiddle/go/jsfiddle/main.go
index d4a3e56..e7bc686 100644
--- a/jsfiddle/go/jsfiddle/main.go
+++ b/jsfiddle/go/jsfiddle/main.go
@@ -26,7 +26,7 @@
 	resourcesDir = flag.String("resources_dir", "./dist", "The directory to find templates, JS, and CSS files. If blank the current directory will be used.")
 )
 
-const MAX_FIDDLE_SIZE = 10 * 1024 * 1024 // 10KB ought to be enough for anyone.
+const MAX_FIDDLE_SIZE = 100 * 1024 // 100KB ought to be enough for anyone.
 
 var pathkitPage []byte
 var canvaskitPage []byte